@@ -18,6 +18,15 @@ from nbqa.notebook_info import NotebookInfo
 
 CONFIG_FILES = ["setup.cfg", "tox.ini", "pyproject.toml"]
 
+BASE_ERROR_MESSAGE = dedent(
+    """
+
+    😭 {} 😭
+
+    Please report a bug at https://github.com/nbQA-dev/nbQA/issues 🙏
+    """
+)
+
 
 def _get_notebooks(root_dir: str) -> Iterator[Path]:
     """
@@ -62,77 +71,14 @@ def _temp_python_file_for_notebook(
         Temporary Python file whose location mirrors that of the notebook, but
         inside the temporary directory.
     """
-    # Add 3 extra whitespaces because `ipynb` is 3 chars longer than `py`.
-    relative_notebook_dir = notebook.resolve().relative_to(project_root).parent
-    temp_python_file = Path(tmpdir) / relative_notebook_dir / f"{notebook.stem}   .py"
+    relative_notebook_path = (
+        notebook.resolve().relative_to(project_root).with_suffix(".py")
+    )
+    temp_python_file = Path(tmpdir) / relative_notebook_path
     temp_python_file.parent.mkdir(parents=True, exist_ok=True)
     return temp_python_file
 
 
-def _replace_full_path_out_err(
-    out: str, err: str, temp_python_file: Path, notebook: Path
-) -> Tuple[str, str]:
-    """
-    Replace references to temporary Python file's full path with notebook's path.
-
-    Parameters
-    ----------
-    out
-        Captured stdout from third-party tool.
-    err
-        Captured stderr from third-party tool.
-    temp_python_file
-        Temporary Python file where notebook was converted to.
-    notebook
-        Original Jupyter notebook.
-
-    Returns
-    -------
-    out
-        Stdout with temporary Python file's full path with notebook's path.
-    err
-        Stderr with temporary Python file's full path with notebook's path.
-    """
-    out = out.replace(str(temp_python_file), str(notebook.resolve()))
-    err = err.replace(str(temp_python_file), str(notebook.resolve()))
-
-    # This next part is necessary to handle cases when `resolve` changes the path.
-    # I couldn't reproduce this locally, but during CI, on the Windows job, I found
-    # that VSSADM~1 was changing into VssAdministrator.
-    out = out.replace(str(temp_python_file.resolve()), str(notebook.resolve()))
-    err = err.replace(str(temp_python_file.resolve()), str(notebook.resolve()))
-    return out, err
-
-
-def _replace_relative_path_out_err(out: str, notebook: Path) -> str:
-    """
-    Replace references to temporary Python file's relative path with notebook's path.
-
-    Parameters
-    ----------
-    out
-        Captured stdout from third-party tool.
-    notebook
-        Original Jupyter notebook.
-
-    Returns
-    -------
-    out
-        Stdout with temporary Python file's relative path with notebook's path.
-    Examples
-    --------
-    >>> out = "notebook   .py ."
-    >>> notebook = Path('notebook.ipynb')
-    >>> _replace_relative_path_out_err(out, notebook)
-    'notebook.ipynb .'
-    """
-    out = out.replace(
-        str(notebook.parent.joinpath(f"{notebook.stem}   ").with_suffix(".py")),
-        str(notebook),
-    )
-    return out
-
-
 def _map_python_line_to_nb_lines(
     out: str, notebook: Path, cell_mapping: Mapping[int, str]
 ) -> str:
@@ -172,17 +118,19 @@ def _map_python_line_to_nb_lines(
 
 
 def _replace_temp_python_file_references_in_out_err(
+    tmpdirname: str,
     temp_python_file: Path,
     notebook: Path,
     out: str,
     err: str,
-    cell_mapping: Mapping[int, str],
 ) -> Tuple[str, str]:
     """
     Replace references to temporary Python file with references to notebook.
 
     Parameters
     ----------
+    tmpdirname
+        Temporary directory used for converting notebooks to python files
     temp_python_file
         Temporary Python file where notebook was converted to.
     notebook
@@ -191,8 +139,6 @@ def _replace_temp_python_file_references_in_out_err(
         Captured stdout from third-party tool.
     err
         Captured stderr from third-party tool.
-    cell_mapping
-        Mapping from Python lines to Jupyter notebook cells.
 
     Returns
     -------
@@ -201,9 +147,27 @@ def _replace_temp_python_file_references_in_out_err(
     err
         Stderr with temporary directory replaced by current working directory.
     """
-    out, err = _replace_full_path_out_err(out, err, temp_python_file, notebook)
-    out = _replace_relative_path_out_err(out, notebook)
-    out = _map_python_line_to_nb_lines(out, notebook, cell_mapping)
+    # 1. Relative path is used because some tools like pylint always report only
+    # the relative path of the file(relative to project root),
+    # though absolute path was passed as the input.
+    # 2. This `resolve()` part is necessary to handle cases when the path used
+    # is a symlink as well as no normalize the path.
+    # I couldn't reproduce this locally, but during CI, on the Windows job, I found
+    # that VSSADM~1 was changing into VssAdministrator.
+    paths = (
+        str(path)
+        for path in [
+            temp_python_file,
+            temp_python_file.resolve(),
+            temp_python_file.relative_to(tmpdirname),
+        ]
+    )
+
+    notebook_path = str(notebook)
+    for path in paths:
+        out = out.replace(path, notebook_path)
+        err = err.replace(path, notebook_path)
+
     return out, err
 
 
@@ -301,10 +265,10 @@ def _get_arg(
     >>> root_dir = "root_dir"
     >>> tmpdirname = "tmpdir"
     >>> nb_to_py_mapping = {
-    ...     Path('my_notebook.ipynb'): Path('tmpdir').joinpath('my_notebook   .py')
+    ...     Path('my_notebook.ipynb'): Path('tmpdir').joinpath('my_notebook.py')
     ... }
     >>> _get_arg(root_dir, tmpdirname, nb_to_py_mapping).as_posix()
-    'tmpdir/my_notebook   .py'
+    'tmpdir/my_notebook.py'
     """
     if Path(root_dir).is_dir():
         arg = Path(tmpdirname) / Path(root_dir).resolve().relative_to(project_root)
@@ -330,7 +294,7 @@ def _get_mtimes(arg: Path) -> Set[float]:
     """
     if not arg.is_dir():
         return {os.path.getmtime(str(arg))}
-    return {os.path.getmtime(str(i)) for i in arg.rglob("*   .py")}
+    return {os.path.getmtime(str(i)) for i in arg.rglob("*.py")}
 
 
 def _run_command(
@@ -370,7 +334,9 @@ def _run_command(
         If third-party tool isn't found in system.
     """
     env = os.environ.copy()
-    env["PYTHONPATH"] = os.getcwd()
+    env[
+        "PYTHONPATH"
+    ] = f"{env.get('PYTHONPATH', '').rstrip(os.pathsep)}{os.pathsep}{os.getcwd()}"
 
     before = _get_mtimes(arg)
 
@@ -459,9 +425,18 @@ def _run_on_one_root_dir(
         nb_info_mapping: Dict[Path, NotebookInfo] = {}
 
         for notebook, temp_python_file in nb_to_py_mapping.items():
-            nb_info_mapping[notebook] = save_source.main(
-                notebook, temp_python_file, configs.nbqa_ignore_cells
-            )
+            try:
+                nb_info_mapping[notebook] = save_source.main(
+                    notebook,
+                    temp_python_file,
+                    configs.nbqa_ignore_cells,
+                    cli_args.command,
+                )
+            except Exception as exc:
+                raise RuntimeError(
+                    BASE_ERROR_MESSAGE.format(f"Error parsing {str(notebook)}")
+                ) from exc
+
             _create_blank_init_files(notebook, tmpdirname, project_root)
 
         out, err, output_code, mutated = _run_command(
@@ -473,12 +448,12 @@ def _run_on_one_root_dir(
 
         for notebook, temp_python_file in nb_to_py_mapping.items():
             out, err = _replace_temp_python_file_references_in_out_err(
-                temp_python_file,
-                notebook,
-                out,
-                err,
-                nb_info_mapping[notebook].cell_mappings,
+                tmpdirname, temp_python_file, notebook, out, err
             )
+            out = _map_python_line_to_nb_lines(
+                out, notebook, nb_info_mapping[notebook].cell_mappings
+            )
+
             if mutated:
                 if not configs.nbqa_mutate:
                     raise SystemExit(
@@ -491,9 +466,16 @@ def _run_on_one_root_dir(
                         )
                     )
 
-                replace_source.main(
-                    temp_python_file, notebook, nb_info_mapping[notebook]
-                )
+                try:
+                    replace_source.main(
+                        temp_python_file, notebook, nb_info_mapping[notebook]
+                    )
+                except Exception as exc:
+                    raise RuntimeError(
+                        BASE_ERROR_MESSAGE.format(
+                            f"Error reconstructing {str(notebook)}"
+                        )
+                    ) from exc
 
         sys.stdout.write(out)
         sys.stderr.write(err)
